@@ -23,10 +23,10 @@ from __future__ import with_statement
 import hashlib
 import math
 import urllib
-import urlparse
+
+from oslo.config import cfg
 
 from glance.common import exception
-from glance.openstack.common import cfg
 import glance.openstack.common.log as logging
 import glance.store
 import glance.store.base
@@ -47,11 +47,18 @@ DEFAULT_SNAPNAME = 'snap'
 LOG = logging.getLogger(__name__)
 
 rbd_opts = [
-    cfg.IntOpt('rbd_store_chunk_size', default=DEFAULT_CHUNKSIZE),
-    cfg.StrOpt('rbd_store_pool', default=DEFAULT_POOL),
-    cfg.StrOpt('rbd_store_user', default=DEFAULT_USER),
-    cfg.StrOpt('rbd_store_ceph_conf', default=DEFAULT_CONFFILE),
-    ]
+    cfg.IntOpt('rbd_store_chunk_size', default=DEFAULT_CHUNKSIZE,
+               help=_('Images will be chunked into objects of this size '
+                      '(in megabytes). For best performance, this should be '
+                      'a power of two.')),
+    cfg.StrOpt('rbd_store_pool', default=DEFAULT_POOL,
+               help=_('RADOS pool in which images are stored.')),
+    cfg.StrOpt('rbd_store_user', default=DEFAULT_USER,
+               help=_('RADOS user to authenticate as (only applicable if '
+                      'using cephx.)')),
+    cfg.StrOpt('rbd_store_ceph_conf', default=DEFAULT_CONFFILE,
+               help=_('Ceph configuration file path.')),
+]
 
 CONF = cfg.CONF
 CONF.register_opts(rbd_opts)
@@ -93,14 +100,14 @@ class StoreLocation(glance.store.location.StoreLocation):
         prefix = 'rbd://'
         if not uri.startswith(prefix):
             reason = _('URI must start with rbd://')
-            LOG.error(_("Invalid URI: %(uri)s: %(reason)s") % locals())
+            LOG.debug(_("Invalid URI: %(uri)s: %(reason)s") % locals())
             raise exception.BadStoreUri(message=reason)
         # convert to ascii since librbd doesn't handle unicode
         try:
             ascii_uri = str(uri)
         except UnicodeError:
             reason = _('URI contains non-ascii characters')
-            LOG.error(_("Invalid URI: %(uri)s: %(reason)s") % locals())
+            LOG.debug(_("Invalid URI: %(uri)s: %(reason)s") % locals())
             raise exception.BadStoreUri(message=reason)
         pieces = ascii_uri[len(prefix):].split('/')
         if len(pieces) == 1:
@@ -111,11 +118,11 @@ class StoreLocation(glance.store.location.StoreLocation):
                 map(urllib.unquote, pieces)
         else:
             reason = _('URI must have exactly 1 or 4 components')
-            LOG.error(_("Invalid URI: %(uri)s: %(reason)s") % locals())
+            LOG.debug(_("Invalid URI: %(uri)s: %(reason)s") % locals())
             raise exception.BadStoreUri(message=reason)
         if any(map(lambda p: p == '', pieces)):
             reason = _('URI cannot contain empty components')
-            LOG.error(_("Invalid URI: %(uri)s: %(reason)s") % locals())
+            LOG.debug(_("Invalid URI: %(uri)s: %(reason)s") % locals())
             raise exception.BadStoreUri(message=reason)
 
 
@@ -206,11 +213,11 @@ class Store(glance.store.base.Store):
             librbd.create(ioctx, name, size, order, old_format=False,
                           features=rbd.RBD_FEATURE_LAYERING)
             return StoreLocation({
-                    'fsid': fsid,
-                    'pool': self.pool,
-                    'image': name,
-                    'snapshot': DEFAULT_SNAPNAME,
-                    })
+                'fsid': fsid,
+                'pool': self.pool,
+                'image': name,
+                'snapshot': DEFAULT_SNAPNAME,
+            })
         else:
             librbd.create(ioctx, name, size, order, old_format=True)
             return StoreLocation({'image': name})
@@ -218,14 +225,14 @@ class Store(glance.store.base.Store):
     def add(self, image_id, image_file, image_size):
         """
         Stores an image file with supplied identifier to the backend
-        storage system and returns an `glance.store.ImageAddResult` object
-        containing information about the stored image.
+        storage system and returns a tuple containing information
+        about the stored image.
 
         :param image_id: The opaque image identifier
         :param image_file: The image data to write, as a file-like object
         :param image_size: The size of the image data to write, in bytes
 
-        :retval `glance.store.ImageAddResult` object
+        :retval tuple of URL in backing store, bytes written, and checksum
         :raises `glance.common.exception.Duplicate` if the image already
                 existed
         """
@@ -280,7 +287,7 @@ class Store(glance.store.base.Store):
                         except rbd.ImageBusy:
                             log_msg = _("snapshot %s@%s could not be "
                                         "unprotected because it is in use")
-                            LOG.error(log_msg % (loc.image, loc.snapshot))
+                            LOG.debug(log_msg % (loc.image, loc.snapshot))
                             raise exception.InUseByStore()
                         image.remove_snap(loc.snapshot)
                 try:
@@ -291,5 +298,5 @@ class Store(glance.store.base.Store):
                 except rbd.ImageBusy:
                     log_msg = _("image %s could not be removed"
                                 "because it is in use")
-                    LOG.error(log_msg % loc.image)
+                    LOG.debug(log_msg % loc.image)
                     raise exception.InUseByStore()
