@@ -32,13 +32,11 @@ import httplib2
 
 from glance.tests import functional
 from glance.tests.utils import (skip_if_disabled,
-                                requires,
                                 execute,
                                 xattr_writes_supported,
                                 minimal_headers)
 
 from glance.tests.functional.store_utils import (setup_http,
-                                                 teardown_http,
                                                  get_http_uri)
 
 FIVE_KB = 5 * 1024
@@ -134,6 +132,8 @@ class BaseCacheMiddlewareTest(object):
         image_entity = {
             'name': 'Image1',
             'visibility': 'public',
+            'container_format': 'bare',
+            'disk_format': 'raw',
         }
         response, content = http.request(path, 'POST',
                                          headers=headers,
@@ -149,7 +149,7 @@ class BaseCacheMiddlewareTest(object):
         response, content = http.request(path, 'PUT',
                                          headers=headers,
                                          body=image_data)
-        self.assertEqual(response.status, 201)
+        self.assertEqual(response.status, 204)
 
         # Verify image not in cache
         image_cached_path = os.path.join(self.api_server.image_cache_dir,
@@ -177,7 +177,6 @@ class BaseCacheMiddlewareTest(object):
 
         self.stop_servers()
 
-    @requires(teardown=teardown_http)
     @skip_if_disabled
     def test_cache_remote_image(self):
         """
@@ -305,7 +304,7 @@ class BaseCacheManageMiddlewareTest(object):
         self.assertEqual(image_id1, cached_images[0]['image_id'])
 
         # Set policy to disallow access to cache management
-        rules = {"manage_image_cache": [["false:false"]]}
+        rules = {"manage_image_cache": '!'}
         self.set_policy_rules(rules)
 
         # Verify an unprivileged user cannot see cached images
