@@ -43,7 +43,7 @@ class TestGlanceManage(functional.FunctionalTest):
             conf_file.write(self.connection)
             conf_file.flush()
 
-        cmd = ('bin/glance-manage db_sync --config-file %s' %
+        cmd = ('bin/glance-manage --config-file %s db_sync' %
                self.conf_filepath)
         execute(cmd, raise_error=True)
 
@@ -53,6 +53,7 @@ class TestGlanceManage(functional.FunctionalTest):
 
         self.assertTrue('CREATE TABLE images' in out)
         self.assertTrue('CREATE TABLE image_tags' in out)
+        self.assertTrue('CREATE TABLE image_locations' in out)
 
         #NOTE(bcwaldon): For some reason we need double-quotes around
         # these two table names
