@@ -26,7 +26,7 @@ import StringIO
 import mox
 
 from glance.common import exception
-from glance.common import utils
+from glance.openstack.common import uuidutils
 from glance.store.filesystem import Store, ChunkedFile
 from glance.store.location import get_location_from_uri
 from glance.tests.unit import base
@@ -49,9 +49,8 @@ class TestStore(base.IsolatedUnitTest):
     def test_get(self):
         """Test a "normal" retrieval of an image in chunks"""
         # First add an image...
-        image_id = utils.generate_uuid()
+        image_id = uuidutils.generate_uuid()
         file_contents = "chunk00000remainder"
-        location = "file://%s/%s" % (self.test_dir, image_id)
         image_file = StringIO.StringIO(file_contents)
 
         location, size, checksum = self.store.add(image_id,
@@ -87,7 +86,7 @@ class TestStore(base.IsolatedUnitTest):
     def test_add(self):
         """Test that we can add an image via the filesystem backend"""
         ChunkedFile.CHUNKSIZE = 1024
-        expected_image_id = utils.generate_uuid()
+        expected_image_id = uuidutils.generate_uuid()
         expected_file_size = 1024 * 5  # 5K
         expected_file_contents = "*" * expected_file_size
         expected_checksum = hashlib.md5(expected_file_contents).hexdigest()
@@ -122,10 +121,9 @@ class TestStore(base.IsolatedUnitTest):
         raises an appropriate exception
         """
         ChunkedFile.CHUNKSIZE = 1024
-        image_id = utils.generate_uuid()
+        image_id = uuidutils.generate_uuid()
         file_size = 1024 * 5  # 5K
         file_contents = "*" * file_size
-        location = "file://%s/%s" % (self.test_dir, image_id)
         image_file = StringIO.StringIO(file_contents)
 
         location, size, checksum = self.store.add(image_id,
@@ -138,11 +136,10 @@ class TestStore(base.IsolatedUnitTest):
 
     def _do_test_add_write_failure(self, errno, exception):
         ChunkedFile.CHUNKSIZE = 1024
-        image_id = utils.generate_uuid()
+        image_id = uuidutils.generate_uuid()
         file_size = 1024 * 5  # 5K
         file_contents = "*" * file_size
         path = os.path.join(self.test_dir, image_id)
-        location = "file://%s/%s" % (self.test_dir, image_id)
         image_file = StringIO.StringIO(file_contents)
 
         m = mox.Mox()
@@ -196,11 +193,10 @@ class TestStore(base.IsolatedUnitTest):
         failure.
         """
         ChunkedFile.CHUNKSIZE = 1024
-        image_id = utils.generate_uuid()
+        image_id = uuidutils.generate_uuid()
         file_size = 1024 * 5  # 5K
         file_contents = "*" * file_size
         path = os.path.join(self.test_dir, image_id)
-        location = "file://%s/%s" % (self.test_dir, image_id)
         image_file = StringIO.StringIO(file_contents)
 
         def fake_Error(size):
@@ -218,10 +214,9 @@ class TestStore(base.IsolatedUnitTest):
         Test we can delete an existing image in the filesystem store
         """
         # First add an image
-        image_id = utils.generate_uuid()
+        image_id = uuidutils.generate_uuid()
         file_size = 1024 * 5  # 5K
         file_contents = "*" * file_size
-        location = "file://%s/%s" % (self.test_dir, image_id)
         image_file = StringIO.StringIO(file_contents)
 
         location, size, checksum = self.store.add(image_id,
