@@ -17,28 +17,31 @@
 
 """Tests the S3 backend store"""
 
-import StringIO
 import hashlib
-import httplib
-import sys
-import unittest
-import urlparse
+import StringIO
 
-import stubout
 import boto.s3.connection
+import stubout
 
 from glance.common import exception
-from glance.store import BackendException, UnsupportedBackend
+from glance.openstack.common import uuidutils
 from glance.store.location import get_location_from_uri
-from glance.store.s3 import Store
+import glance.store.s3
+from glance.store.s3 import Store, get_s3_location
+from glance.store import UnsupportedBackend
+from glance.tests.unit import base
+
+
+FAKE_UUID = uuidutils.generate_uuid()
 
 FIVE_KB = (5 * 1024)
-S3_OPTIONS = {'verbose': True,
-              'debug': True,
-              's3_store_access_key': 'user',
-              's3_store_secret_key': 'key',
-              's3_store_host': 'localhost:8080',
-              's3_store_bucket': 'glance'}
+S3_CONF = {'verbose': True,
+           'debug': True,
+           'default_store': 's3',
+           's3_store_access_key': 'user',
+           's3_store_secret_key': 'key',
+           's3_store_host': 'localhost:8080',
+           's3_store_bucket': 'glance'}
 
 
 # We stub out as little as possible to ensure that the code paths
@@ -117,7 +120,7 @@ def stub_out_s3(stubs):
 
     fixture_buckets = {'glance': FakeBucket('glance')}
     b = fixture_buckets['glance']
-    k = b.new_key('2')
+    k = b.new_key(FAKE_UUID)
     k.set_contents_from_file(StringIO.StringIO("*" * FIVE_KB))
 
     def fake_connection_constructor(self, *args, **kwargs):
@@ -153,22 +156,21 @@ def format_s3_location(user, key, authurl, bucket, obj):
                                     bucket, obj)
 
 
-class TestStore(unittest.TestCase):
+class TestStore(base.StoreClearingUnitTest):
 
     def setUp(self):
         """Establish a clean test environment"""
+        self.config(**S3_CONF)
+        super(TestStore, self).setUp()
         self.stubs = stubout.StubOutForTesting()
         stub_out_s3(self.stubs)
-        self.store = Store(S3_OPTIONS)
-
-    def tearDown(self):
-        """Clear the test environment"""
-        self.stubs.UnsetAll()
+        self.store = Store()
+        self.addCleanup(self.stubs.UnsetAll)
 
     def test_get(self):
         """Test a "normal" retrieval of an image in chunks"""
         loc = get_location_from_uri(
-            "s3://user:key@auth_address/glance/2")
+            "s3://user:key@auth_address/glance/%s" % FAKE_UUID)
         (image_s3, image_size) = self.store.get(loc)
 
         self.assertEqual(image_size, FIVE_KB)
@@ -180,38 +182,66 @@ class TestStore(unittest.TestCase):
             data += chunk
         self.assertEqual(expected_data, data)
 
+    def test_get_calling_format_path(self):
+        """Test a "normal" retrieval of an image in chunks"""
+        self.config(s3_store_bucket_url_format='path')
+
+        def fake_S3Connection_init(*args, **kwargs):
+            expected_cls = boto.s3.connection.OrdinaryCallingFormat
+            self.assertTrue(isinstance(kwargs.get('calling_format'),
+                                       expected_cls))
+
+        self.stubs.Set(boto.s3.connection.S3Connection, '__init__',
+                       fake_S3Connection_init)
+
+        loc = get_location_from_uri(
+            "s3://user:key@auth_address/glance/%s" % FAKE_UUID)
+        (image_s3, image_size) = self.store.get(loc)
+
+    def test_get_calling_format_default(self):
+        """Test a "normal" retrieval of an image in chunks"""
+
+        def fake_S3Connection_init(*args, **kwargs):
+            expected_cls = boto.s3.connection.SubdomainCallingFormat
+            self.assertTrue(isinstance(kwargs.get('calling_format'),
+                                       expected_cls))
+
+        self.stubs.Set(boto.s3.connection.S3Connection, '__init__',
+                       fake_S3Connection_init)
+
+        loc = get_location_from_uri(
+            "s3://user:key@auth_address/glance/%s" % FAKE_UUID)
+        (image_s3, image_size) = self.store.get(loc)
+
     def test_get_non_existing(self):
         """
         Test that trying to retrieve a s3 that doesn't exist
         raises an error
         """
-        loc = get_location_from_uri(
-            "s3://user:key@auth_address/badbucket/2")
-        self.assertRaises(exception.NotFound,
-                          self.store.get,
-                          loc)
+        uri = "s3://user:key@auth_address/badbucket/%s" % FAKE_UUID
+        loc = get_location_from_uri(uri)
+        self.assertRaises(exception.NotFound, self.store.get, loc)
 
-        loc = get_location_from_uri(
-            "s3://user:key@auth_address/glance/noexist")
-        self.assertRaises(exception.NotFound,
-                          self.store.get,
-                          loc)
+        uri = "s3://user:key@auth_address/glance/noexist"
+        loc = get_location_from_uri(uri)
+        self.assertRaises(exception.NotFound, self.store.get, loc)
 
     def test_add(self):
         """Test that we can add an image via the s3 backend"""
-        expected_image_id = 42
+        expected_image_id = uuidutils.generate_uuid()
         expected_s3_size = FIVE_KB
         expected_s3_contents = "*" * expected_s3_size
         expected_checksum = hashlib.md5(expected_s3_contents).hexdigest()
         expected_location = format_s3_location(
-            S3_OPTIONS['s3_store_access_key'],
-            S3_OPTIONS['s3_store_secret_key'],
-            S3_OPTIONS['s3_store_host'],
-            S3_OPTIONS['s3_store_bucket'],
+            S3_CONF['s3_store_access_key'],
+            S3_CONF['s3_store_secret_key'],
+            S3_CONF['s3_store_host'],
+            S3_CONF['s3_store_bucket'],
             expected_image_id)
         image_s3 = StringIO.StringIO(expected_s3_contents)
 
-        location, size, checksum = self.store.add(42, image_s3,
+        location, size, checksum = self.store.add(expected_image_id,
+                                                  image_s3,
                                                   expected_s3_size)
 
         self.assertEquals(expected_location, location)
@@ -243,25 +273,25 @@ class TestStore(unittest.TestCase):
                       'https://localhost/v1/',
                       'localhost',
                       'localhost:8080/v1']
-        i = 42
         for variation in variations:
-            expected_image_id = i
+            expected_image_id = uuidutils.generate_uuid()
             expected_s3_size = FIVE_KB
             expected_s3_contents = "*" * expected_s3_size
-            expected_checksum = \
-                    hashlib.md5(expected_s3_contents).hexdigest()
-            new_options = S3_OPTIONS.copy()
-            new_options['s3_store_host'] = variation
+            expected_checksum = hashlib.md5(expected_s3_contents).hexdigest()
+            new_conf = S3_CONF.copy()
+            new_conf['s3_store_host'] = variation
             expected_location = format_s3_location(
-                new_options['s3_store_access_key'],
-                new_options['s3_store_secret_key'],
-                new_options['s3_store_host'],
-                new_options['s3_store_bucket'],
+                new_conf['s3_store_access_key'],
+                new_conf['s3_store_secret_key'],
+                new_conf['s3_store_host'],
+                new_conf['s3_store_bucket'],
                 expected_image_id)
             image_s3 = StringIO.StringIO(expected_s3_contents)
 
-            self.store = Store(new_options)
-            location, size, checksum = self.store.add(i, image_s3,
+            self.config(**new_conf)
+            self.store = Store()
+            location, size, checksum = self.store.add(expected_image_id,
+                                                      image_s3,
                                                       expected_s3_size)
 
             self.assertEquals(expected_location, location)
@@ -271,11 +301,10 @@ class TestStore(unittest.TestCase):
             loc = get_location_from_uri(expected_location)
             (new_image_s3, new_image_size) = self.store.get(loc)
             new_image_contents = new_image_s3.getvalue()
-            new_image_s3_size = new_image_s3.len
+            new_image_s3_size = len(new_image_s3)
 
             self.assertEquals(expected_s3_contents, new_image_contents)
             self.assertEquals(expected_s3_size, new_image_s3_size)
-            i = i + 1
 
     def test_add_already_existing(self):
         """
@@ -285,16 +314,17 @@ class TestStore(unittest.TestCase):
         image_s3 = StringIO.StringIO("nevergonnamakeit")
         self.assertRaises(exception.Duplicate,
                           self.store.add,
-                          2, image_s3, 0)
+                          FAKE_UUID, image_s3, 0)
 
     def _option_required(self, key):
-        options = S3_OPTIONS.copy()
-        del options[key]
+        conf = S3_CONF.copy()
+        conf[key] = None
 
         try:
-            self.store = Store(options)
+            self.config(**conf)
+            self.store = Store()
             return self.store.add == self.store.add_disabled
-        except:
+        except Exception:
             return False
         return False
 
@@ -320,22 +350,66 @@ class TestStore(unittest.TestCase):
         """
         Test we can delete an existing image in the s3 store
         """
-        loc = get_location_from_uri(
-            "s3://user:key@auth_address/glance/2")
-
+        uri = "s3://user:key@auth_address/glance/%s" % FAKE_UUID
+        loc = get_location_from_uri(uri)
         self.store.delete(loc)
 
-        self.assertRaises(exception.NotFound,
-                          self.store.get,
-                          loc)
+        self.assertRaises(exception.NotFound, self.store.get, loc)
 
     def test_delete_non_existing(self):
         """
         Test that trying to delete a s3 that doesn't exist
         raises an error
         """
-        loc = get_location_from_uri(
-            "s3://user:key@auth_address/glance/noexist")
-        self.assertRaises(exception.NotFound,
-                          self.store.delete,
-                          loc)
+        uri = "s3://user:key@auth_address/glance/noexist"
+        loc = get_location_from_uri(uri)
+        self.assertRaises(exception.NotFound, self.store.delete, loc)
+
+    def _do_test_get_s3_location(self, host, loc):
+        self.assertEquals(get_s3_location(host), loc)
+        self.assertEquals(get_s3_location(host + ':80'), loc)
+        self.assertEquals(get_s3_location('http://' + host), loc)
+        self.assertEquals(get_s3_location('http://' + host + ':80'), loc)
+        self.assertEquals(get_s3_location('https://' + host), loc)
+        self.assertEquals(get_s3_location('https://' + host + ':80'), loc)
+
+    def test_get_s3_good_location(self):
+        """
+        Test that the s3 location can be derived from the host
+        """
+        good_locations = [
+            ('s3.amazonaws.com', ''),
+            ('s3-eu-west-1.amazonaws.com', 'EU'),
+            ('s3-us-west-1.amazonaws.com', 'us-west-1'),
+            ('s3-ap-southeast-1.amazonaws.com', 'ap-southeast-1'),
+            ('s3-ap-northeast-1.amazonaws.com', 'ap-northeast-1'),
+        ]
+        for (url, expected) in good_locations:
+            self._do_test_get_s3_location(url, expected)
+
+    def test_get_s3_bad_location(self):
+        """
+        Test that the s3 location cannot be derived from an unexpected host
+        """
+        bad_locations = [
+            ('', ''),
+            ('s3.amazon.co.uk', ''),
+            ('s3-govcloud.amazonaws.com', ''),
+            ('cloudfiles.rackspace.com', ''),
+        ]
+        for (url, expected) in bad_locations:
+            self._do_test_get_s3_location(url, expected)
+
+    def test_calling_format_path(self):
+        self.config(s3_store_bucket_url_format='path')
+        self.assertTrue(isinstance(glance.store.s3.get_calling_format(),
+                                   boto.s3.connection.OrdinaryCallingFormat))
+
+    def test_calling_format_subdomain(self):
+        self.config(s3_store_bucket_url_format='subdomain')
+        self.assertTrue(isinstance(glance.store.s3.get_calling_format(),
+                                   boto.s3.connection.SubdomainCallingFormat))
+
+    def test_calling_format_default(self):
+        self.assertTrue(isinstance(glance.store.s3.get_calling_format(),
+                                   boto.s3.connection.SubdomainCallingFormat))
