@@ -1,4 +1,4 @@
-# Copyright 2012 OpenStack LLC.
+# Copyright 2012 OpenStack Foundation.
 # All Rights Reserved.
 #
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
@@ -35,19 +35,19 @@ USER3 = '2hss8dkl-d8jh-88yd-uhs9-879sdjsd8skd'
 BASE_URI = 'swift+http://storeurl.com/container'
 
 
-def get_fake_request(path='', method='POST', is_admin=False, user=USER1):
+def get_fake_request(path='', method='POST', is_admin=False, user=USER1,
+                     tenant=TENANT1):
     req = wsgi.Request.blank(path)
     req.method = method
 
     kwargs = {
-            'user': user,
-            'tenant': TENANT1,
-            'roles': [],
-            'is_admin': is_admin,
-        }
+        'user': user,
+        'tenant': tenant,
+        'roles': [],
+        'is_admin': is_admin,
+    }
 
     req.context = glance.context.RequestContext(**kwargs)
-
     return req
 
 
@@ -61,7 +61,7 @@ class FakeDB(object):
     def init_db():
         images = [
             {'id': UUID1, 'owner': TENANT1, 'status': 'queued',
-             'location': '%s/%s' % (BASE_URI, UUID1)},
+             'locations': ['%s/%s' % (BASE_URI, UUID1)]},
             {'id': UUID2, 'owner': TENANT1, 'status': 'queued'},
         ]
         [simple_db.image_create(None, image) for image in images]
@@ -91,12 +91,18 @@ class FakeStoreAPI(object):
         self.data = {
             '%s/%s' % (BASE_URI, UUID1): ('XXX', 3),
         }
+        self.acls = {}
 
     def create_stores(self):
         pass
 
-    def set_acls(*_args, **_kwargs):
-        pass
+    def set_acls(self, context, uri, public=False,
+                 read_tenants=[], write_tenants=[]):
+        self.acls[uri] = {
+            'public': public,
+            'read': read_tenants,
+            'write': write_tenants,
+        }
 
     def get_from_backend(self, context, location):
         try:
@@ -122,13 +128,15 @@ class FakeStoreAPI(object):
         for location in self.data.keys():
             if image_id in location:
                 raise exception.Duplicate()
-        if size and (current_store_size + size) > store_max_size:
+        if not size:
+            size = len(data.fd)
+        if (current_store_size + size) > store_max_size:
             raise exception.StorageFull()
         if context.user == USER2:
             raise exception.Forbidden()
         if context.user == USER3:
             raise exception.StorageWriteDenied()
-        self.data[image_id] = (data, size or len(data))
+        self.data[image_id] = (data, size)
         checksum = 'Z'
         return (image_id, size, checksum)
 
@@ -148,24 +156,28 @@ class FakePolicyEnforcer(object):
 
 class FakeNotifier(object):
     def __init__(self, *_args, **kwargs):
-        self.log = {'notification_type': "",
-                    'event_type': "",
-                    'payload': "", }
+        self.log = []
 
     def warn(self, event_type, payload):
-        self.log['notification_type'] = "WARN"
-        self.log['event_type'] = event_type
-        self.log['payload'] = payload
+        log = {}
+        log['notification_type'] = "WARN"
+        log['event_type'] = event_type
+        log['payload'] = payload
+        self.log.append(log)
 
     def info(self, event_type, payload):
-        self.log['notification_type'] = "INFO"
-        self.log['event_type'] = event_type
-        self.log['payload'] = payload
+        log = {}
+        log['notification_type'] = "INFO"
+        log['event_type'] = event_type
+        log['payload'] = payload
+        self.log.append(log)
 
     def error(self, event_type, payload):
-        self.log['notification_type'] = "ERROR"
-        self.log['event_type'] = event_type
-        self.log['payload'] = payload
+        log = {}
+        log['notification_type'] = "ERROR"
+        log['event_type'] = event_type
+        log['payload'] = payload
+        self.log.append(log)
 
-    def get_log(self):
+    def get_logs(self):
         return self.log
